@@ -255,6 +255,32 @@ class PipelineServiceAsyncClient:
         r"""Creates a TrainingPipeline. A created
         TrainingPipeline right away will be attempted to be run.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_create_training_pipeline():
+                # Create a client
+                client = aiplatform_v1beta1.PipelineServiceClient()
+
+                # Initialize request argument(s)
+                training_pipeline = aiplatform_v1beta1.TrainingPipeline()
+                training_pipeline.display_name = "display_name_value"
+                training_pipeline.training_task_definition = "training_task_definition_value"
+                training_pipeline.training_task_inputs.null_value = "NULL_VALUE"
+
+                request = aiplatform_v1beta1.CreateTrainingPipelineRequest(
+                    parent="parent_value",
+                    training_pipeline=training_pipeline,
+                )
+
+                # Make the request
+                response = client.create_training_pipeline(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CreateTrainingPipelineRequest, dict]):
                 The request object. Request message for
@@ -340,6 +366,25 @@ class PipelineServiceAsyncClient:
     ) -> training_pipeline.TrainingPipeline:
         r"""Gets a TrainingPipeline.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_get_training_pipeline():
+                # Create a client
+                client = aiplatform_v1beta1.PipelineServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.GetTrainingPipelineRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_training_pipeline(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.GetTrainingPipelineRequest, dict]):
                 The request object. Request message for
@@ -416,6 +461,26 @@ class PipelineServiceAsyncClient:
     ) -> pagers.ListTrainingPipelinesAsyncPager:
         r"""Lists TrainingPipelines in a Location.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_training_pipelines():
+                # Create a client
+                client = aiplatform_v1beta1.PipelineServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListTrainingPipelinesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_training_pipelines(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListTrainingPipelinesRequest, dict]):
                 The request object. Request message for
@@ -497,6 +562,29 @@ class PipelineServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a TrainingPipeline.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_delete_training_pipeline():
+                # Create a client
+                client = aiplatform_v1beta1.PipelineServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.DeleteTrainingPipelineRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_training_pipeline(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.DeleteTrainingPipelineRequest, dict]):
                 The request object. Request message for
@@ -602,6 +690,23 @@ class PipelineServiceAsyncClient:
         [TrainingPipeline.state][google.cloud.aiplatform.v1beta1.TrainingPipeline.state]
         is set to ``CANCELLED``.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_cancel_training_pipeline():
+                # Create a client
+                client = aiplatform_v1beta1.PipelineServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.CancelTrainingPipelineRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.cancel_training_pipeline(request=request)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CancelTrainingPipelineRequest, dict]):
                 The request object. Request message for
@@ -670,6 +775,26 @@ class PipelineServiceAsyncClient:
         r"""Creates a PipelineJob. A PipelineJob will run
         immediately when created.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_create_pipeline_job():
+                # Create a client
+                client = aiplatform_v1beta1.PipelineServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.CreatePipelineJobRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_pipeline_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CreatePipelineJobRequest, dict]):
                 The request object. Request message for
@@ -762,6 +887,25 @@ class PipelineServiceAsyncClient:
     ) -> pipeline_job.PipelineJob:
         r"""Gets a PipelineJob.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_get_pipeline_job():
+                # Create a client
+                client = aiplatform_v1beta1.PipelineServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.GetPipelineJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_pipeline_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.GetPipelineJobRequest, dict]):
                 The request object. Request message for
@@ -833,6 +977,26 @@ class PipelineServiceAsyncClient:
     ) -> pagers.ListPipelineJobsAsyncPager:
         r"""Lists PipelineJobs in a Location.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_pipeline_jobs():
+                # Create a client
+                client = aiplatform_v1beta1.PipelineServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListPipelineJobsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_pipeline_jobs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListPipelineJobsRequest, dict]):
                 The request object. Request message for
@@ -914,6 +1078,29 @@ class PipelineServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a PipelineJob.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_delete_pipeline_job():
+                # Create a client
+                client = aiplatform_v1beta1.PipelineServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.DeletePipelineJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_pipeline_job(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.DeletePipelineJobRequest, dict]):
                 The request object. Request message for
@@ -1019,6 +1206,23 @@ class PipelineServiceAsyncClient:
         [PipelineJob.state][google.cloud.aiplatform.v1beta1.PipelineJob.state]
         is set to ``CANCELLED``.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_cancel_pipeline_job():
+                # Create a client
+                client = aiplatform_v1beta1.PipelineServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.CancelPipelineJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.cancel_pipeline_job(request=request)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CancelPipelineJobRequest, dict]):
                 The request object. Request message for
